# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist
from ourskyai_sda_api.models.fits_header import FitsHeader

class V1ImageSetImage(BaseModel):
    """
    Image Set Image  # noqa: E501
    """
    id: StrictStr = Field(...)
    thumbnail_url: Optional[StrictStr] = Field(None, alias="thumbnailUrl")
    image_url: StrictStr = Field(..., alias="imageUrl")
    full_jpg_url: Optional[StrictStr] = Field(None, alias="fullJpgUrl")
    node_id: StrictStr = Field(..., alias="nodeId")
    target_id: Optional[StrictStr] = Field(None, alias="targetId")
    ra: Optional[Union[StrictFloat, StrictInt]] = None
    dec: Optional[Union[StrictFloat, StrictInt]] = None
    image_set_id: StrictStr = Field(..., alias="imageSetId")
    dark_calibrated: StrictBool = Field(..., alias="darkCalibrated")
    flat_calibrated: StrictBool = Field(..., alias="flatCalibrated")
    bias_calibrated: StrictBool = Field(..., alias="biasCalibrated")
    fwhm_average: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="fwhmAverage")
    fwhm_std_dev: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="fwhmStdDev")
    fwhm_angle: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="fwhmAngle")
    ra_offset: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="raOffset")
    dec_offset: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="decOffset")
    total_offset: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="totalOffset")
    total_offset_std_dev: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="totalOffsetStdDev")
    total_offset_rms: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="totalOffsetRMS")
    captured_at: datetime = Field(..., alias="capturedAt")
    created_at: datetime = Field(..., alias="createdAt")
    binning: Optional[StrictInt] = None
    exposure_length: Union[StrictFloat, StrictInt] = Field(..., alias="exposureLength")
    fits_headers: conlist(FitsHeader) = Field(..., alias="fitsHeaders")
    __properties = ["id", "thumbnailUrl", "imageUrl", "fullJpgUrl", "nodeId", "targetId", "ra", "dec", "imageSetId", "darkCalibrated", "flatCalibrated", "biasCalibrated", "fwhmAverage", "fwhmStdDev", "fwhmAngle", "raOffset", "decOffset", "totalOffset", "totalOffsetStdDev", "totalOffsetRMS", "capturedAt", "createdAt", "binning", "exposureLength", "fitsHeaders"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ImageSetImage:
        """Create an instance of V1ImageSetImage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in fits_headers (list)
        _items = []
        if self.fits_headers:
            for _item in self.fits_headers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fitsHeaders'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ImageSetImage:
        """Create an instance of V1ImageSetImage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ImageSetImage.parse_obj(obj)

        _obj = V1ImageSetImage.parse_obj({
            "id": obj.get("id"),
            "thumbnail_url": obj.get("thumbnailUrl"),
            "image_url": obj.get("imageUrl"),
            "full_jpg_url": obj.get("fullJpgUrl"),
            "node_id": obj.get("nodeId"),
            "target_id": obj.get("targetId"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "image_set_id": obj.get("imageSetId"),
            "dark_calibrated": obj.get("darkCalibrated"),
            "flat_calibrated": obj.get("flatCalibrated"),
            "bias_calibrated": obj.get("biasCalibrated"),
            "fwhm_average": obj.get("fwhmAverage"),
            "fwhm_std_dev": obj.get("fwhmStdDev"),
            "fwhm_angle": obj.get("fwhmAngle"),
            "ra_offset": obj.get("raOffset"),
            "dec_offset": obj.get("decOffset"),
            "total_offset": obj.get("totalOffset"),
            "total_offset_std_dev": obj.get("totalOffsetStdDev"),
            "total_offset_rms": obj.get("totalOffsetRMS"),
            "captured_at": obj.get("capturedAt"),
            "created_at": obj.get("createdAt"),
            "binning": obj.get("binning"),
            "exposure_length": obj.get("exposureLength"),
            "fits_headers": [FitsHeader.from_dict(_item) for _item in obj.get("fitsHeaders")] if obj.get("fitsHeaders") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class V1TargetCorrelation(BaseModel):
    """
    Target Correlation  # noqa: E501
    """
    target_id: StrictStr = Field(..., alias="targetId")
    ra: Union[StrictFloat, StrictInt] = Field(..., description="The predicted (propagated) center of the targetId in Right Ascension in degrees")
    dec: Union[StrictFloat, StrictInt] = Field(..., description="The predicted (propagated) center of the streak in Declination in degrees")
    streak_length: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="streakLength", description="The predicted (propagated) length of the target streak in degrees")
    distance_from_streak: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="distanceFromStreak", description="The distance between the predicted and actual center of the streak in degrees")
    angle_from_streak: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="angleFromStreak", description="The angle between the predicted and actual angle-to-celestial-north for the streak in degrees")
    __properties = ["targetId", "ra", "dec", "streakLength", "distanceFromStreak", "angleFromStreak"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1TargetCorrelation:
        """Create an instance of V1TargetCorrelation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1TargetCorrelation:
        """Create an instance of V1TargetCorrelation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1TargetCorrelation.parse_obj(obj)

        _obj = V1TargetCorrelation.parse_obj({
            "target_id": obj.get("targetId"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "streak_length": obj.get("streakLength"),
            "distance_from_streak": obj.get("distanceFromStreak"),
            "angle_from_streak": obj.get("angleFromStreak")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from ourskyai_sda_api.models.observation_quality import ObservationQuality
from ourskyai_sda_api.models.observation_result import ObservationResult

class V1ObservationSequenceResultImageSetsInner(BaseModel):
    """
    V1ObservationSequenceResultImageSetsInner
    """
    id: StrictStr = Field(...)
    node_id: StrictStr = Field(..., alias="nodeId")
    covariance: conlist(conlist(Union[StrictFloat, StrictInt])) = Field(..., description="The covariance matrix of the image set RA and Dec platesolve offset average. This is a 2D array of doubles - rows of columns")
    observation_results: conlist(ObservationResult) = Field(..., alias="observationResults")
    observation_quality: Optional[ObservationQuality] = Field(None, alias="observationQuality")
    __properties = ["id", "nodeId", "covariance", "observationResults", "observationQuality"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ObservationSequenceResultImageSetsInner:
        """Create an instance of V1ObservationSequenceResultImageSetsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in observation_results (list)
        _items = []
        if self.observation_results:
            for _item in self.observation_results:
                if _item:
                    _items.append(_item.to_dict())
            _dict['observationResults'] = _items
        # override the default output from pydantic by calling `to_dict()` of observation_quality
        if self.observation_quality:
            _dict['observationQuality'] = self.observation_quality.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ObservationSequenceResultImageSetsInner:
        """Create an instance of V1ObservationSequenceResultImageSetsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ObservationSequenceResultImageSetsInner.parse_obj(obj)

        _obj = V1ObservationSequenceResultImageSetsInner.parse_obj({
            "id": obj.get("id"),
            "node_id": obj.get("nodeId"),
            "covariance": obj.get("covariance"),
            "observation_results": [ObservationResult.from_dict(_item) for _item in obj.get("observationResults")] if obj.get("observationResults") is not None else None,
            "observation_quality": ObservationQuality.from_dict(obj.get("observationQuality")) if obj.get("observationQuality") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class WebhookAuthType(str, Enum):
    """
    Authorization mechanism required for webhook endpoint, if any. Use `NONE` if not required.
    """

    """
    allowed enum values
    """
    NONE = 'NONE'
    BASIC = 'BASIC'
    BEARER = 'BEARER'

    @classmethod
    def from_json(cls, json_str: str) -> WebhookAuthType:
        """Create an instance of WebhookAuthType from a JSON string"""
        return WebhookAuthType(json.loads(json_str))





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from ourskyai_sda_api.models.v1_observation_sequence_result_image_sets_inner import V1ObservationSequenceResultImageSetsInner

class V1ObservationSequenceResult(BaseModel):
    """
    Observation Sequence Result  # noqa: E501
    """
    id: StrictStr = Field(...)
    target_id: StrictStr = Field(..., alias="targetId")
    norad_id: Optional[StrictStr] = Field(None, alias="noradId")
    image_sets: conlist(V1ObservationSequenceResultImageSetsInner) = Field(..., alias="imageSets")
    created_at: datetime = Field(..., alias="createdAt")
    created_by: StrictStr = Field(..., alias="createdBy")
    __properties = ["id", "targetId", "noradId", "imageSets", "createdAt", "createdBy"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ObservationSequenceResult:
        """Create an instance of V1ObservationSequenceResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in image_sets (list)
        _items = []
        if self.image_sets:
            for _item in self.image_sets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['imageSets'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ObservationSequenceResult:
        """Create an instance of V1ObservationSequenceResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ObservationSequenceResult.parse_obj(obj)

        _obj = V1ObservationSequenceResult.parse_obj({
            "id": obj.get("id"),
            "target_id": obj.get("targetId"),
            "norad_id": obj.get("noradId"),
            "image_sets": [V1ObservationSequenceResultImageSetsInner.from_dict(_item) for _item in obj.get("imageSets")] if obj.get("imageSets") is not None else None,
            "created_at": obj.get("createdAt"),
            "created_by": obj.get("createdBy")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from ourskyai_sda_api.models.location import Location
from ourskyai_sda_api.models.mount_type import MountType
from ourskyai_sda_api.models.shutter_type import ShutterType

class V1GroundStationParticipant(BaseModel):
    """
    V1GroundStationParticipant
    """
    node_id: StrictStr = Field(..., alias="nodeId")
    location: Location = Field(...)
    megapixels: Union[StrictFloat, StrictInt] = Field(...)
    shutter_type: ShutterType = Field(..., alias="shutterType")
    pixel_size_microns: Union[StrictFloat, StrictInt] = Field(..., alias="pixelSizeMicrons")
    gps_timestamps: StrictBool = Field(..., alias="gpsTimestamps")
    ota_focal_length_mm: StrictInt = Field(..., alias="otaFocalLengthMm")
    ota_aperture_mm: StrictInt = Field(..., alias="otaApertureMm")
    mount_type: MountType = Field(..., alias="mountType")
    master_flat: Optional[StrictStr] = Field(None, alias="masterFlat")
    master_dark: Optional[StrictStr] = Field(None, alias="masterDark")
    master_bias: Optional[StrictStr] = Field(None, alias="masterBias")
    __properties = ["nodeId", "location", "megapixels", "shutterType", "pixelSizeMicrons", "gpsTimestamps", "otaFocalLengthMm", "otaApertureMm", "mountType", "masterFlat", "masterDark", "masterBias"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1GroundStationParticipant:
        """Create an instance of V1GroundStationParticipant from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1GroundStationParticipant:
        """Create an instance of V1GroundStationParticipant from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1GroundStationParticipant.parse_obj(obj)

        _obj = V1GroundStationParticipant.parse_obj({
            "node_id": obj.get("nodeId"),
            "location": Location.from_dict(obj.get("location")) if obj.get("location") is not None else None,
            "megapixels": obj.get("megapixels"),
            "shutter_type": obj.get("shutterType"),
            "pixel_size_microns": obj.get("pixelSizeMicrons"),
            "gps_timestamps": obj.get("gpsTimestamps"),
            "ota_focal_length_mm": obj.get("otaFocalLengthMm"),
            "ota_aperture_mm": obj.get("otaApertureMm"),
            "mount_type": obj.get("mountType"),
            "master_flat": obj.get("masterFlat"),
            "master_dark": obj.get("masterDark"),
            "master_bias": obj.get("masterBias")
        })
        return _obj





# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3750
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from ourskyai_sda_api.models.observation_state import ObservationState
from ourskyai_sda_api.models.tracking_type import TrackingType

class V1ObservationStatus(BaseModel):
    """
    V1ObservationStatus
    """
    id: StrictStr = Field(...)
    target_id: StrictStr = Field(..., alias="targetId")
    tracking_type: Optional[TrackingType] = Field(None, alias="trackingType")
    ra: Union[StrictFloat, StrictInt] = Field(...)
    dec: Union[StrictFloat, StrictInt] = Field(...)
    observation_time: datetime = Field(..., alias="observationTime")
    tle_line1: StrictStr = Field(..., alias="tleLine1", description="TLE line 1 of when the observation was tasked")
    tle_line2: StrictStr = Field(..., alias="tleLine2", description="TLE line 2 of when the observation was tasked")
    tle_epoch: datetime = Field(..., alias="tleEpoch")
    image_set_id: Optional[StrictStr] = Field(None, alias="imageSetId")
    observation_sequence_result_id: Optional[StrictStr] = Field(None, alias="observationSequenceResultId")
    search_instruction_id: Optional[StrictStr] = Field(None, alias="searchInstructionId")
    survey_instruction_id: Optional[StrictStr] = Field(None, alias="surveyInstructionId")
    completed_at: Optional[datetime] = Field(None, alias="completedAt")
    state: ObservationState = Field(...)
    __properties = ["id", "targetId", "trackingType", "ra", "dec", "observationTime", "tleLine1", "tleLine2", "tleEpoch", "imageSetId", "observationSequenceResultId", "searchInstructionId", "surveyInstructionId", "completedAt", "state"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ObservationStatus:
        """Create an instance of V1ObservationStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ObservationStatus:
        """Create an instance of V1ObservationStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1ObservationStatus.parse_obj(obj)

        _obj = V1ObservationStatus.parse_obj({
            "id": obj.get("id"),
            "target_id": obj.get("targetId"),
            "tracking_type": obj.get("trackingType"),
            "ra": obj.get("ra"),
            "dec": obj.get("dec"),
            "observation_time": obj.get("observationTime"),
            "tle_line1": obj.get("tleLine1"),
            "tle_line2": obj.get("tleLine2"),
            "tle_epoch": obj.get("tleEpoch"),
            "image_set_id": obj.get("imageSetId"),
            "observation_sequence_result_id": obj.get("observationSequenceResultId"),
            "search_instruction_id": obj.get("searchInstructionId"),
            "survey_instruction_id": obj.get("surveyInstructionId"),
            "completed_at": obj.get("completedAt"),
            "state": obj.get("state")
        })
        return _obj


